function int=GLaKF(m,a,f)
%Vstupy
%m - počet kořenů nebo-li stupeň poylnomu
%a - hodnota konstanty alfa
%f - integrovaná funkce
%Výstup
%int - hodnota kvadraturní formule
if a>-1
[x,~]=KLaP(m,a);
A=KGLa(m,a);
int=sum(f(x).*A);
else
string("Parametr alfa musí být větší než -1")
end
